@@ -5,5 +5,9 @@ def round_down(x: float, sig_digits: int) -> float:
     return floor(x * (10**sig_digits)) / (10**sig_digits)
 
 
+def round_normal(x: float, sig_digits: int) -> float:
+    return round(x * (10**sig_digits)) / (10**sig_digits)
+
+
 def to_token_decimals(x: float) -> int:
     return int((10**6) * x)
